#ifndef EXTTEXTCAT_VERSION_H
#define EXTTEXTCAT_VERSION_H

#define EXTTEXTCAT_VERSION "3.4.5"
#define EXTTEXTCAT_VERSION_MAJOR 3
#define EXTTEXTCAT_VERSION_MINOR 4
#define EXTTEXTCAT_VERSION_MICRO 5

#endif
